@@ -338,7 +338,7 @@ async fn test_search_relations_prefixed() -> Result<(), Box<dyn std::error::Erro
         .await?;
     let shard_id = &new_shard_response.get_ref().id;
 
-    let nodes = create_knowledge_graph(&mut writer, shard_id.clone()).await;
+    let _nodes = create_knowledge_graph(&mut writer, shard_id.clone()).await;
 
     // --------------------------------------------------------------
     // Test: prefixed search with empty term. Results are limited
@@ -358,8 +358,10 @@ async fn test_search_relations_prefixed() -> Result<(), Box<dyn std::error::Erro
     assert!(response.get_ref().prefix.is_some());
     let prefix_response = response.get_ref().prefix.as_ref().unwrap();
     let results = &prefix_response.nodes;
-    // TODO: get constants from RelationsReaderService (.../relations/service/reader.rs)
-    assert_eq!(results.len(), nodes.len());
+    // TODO this constants is spread between relations and paragraphs. It should
+    // be in a single place and common for everyone
+    const MAX_SUGGEST_RESULTS: usize = 10;
+    assert_eq!(results.len(), MAX_SUGGEST_RESULTS);
 
     // --------------------------------------------------------------
     // Test: prefixed search with "cat" term (some results)
@@ -376,7 +378,11 @@ async fn test_search_relations_prefixed() -> Result<(), Box<dyn std::error::Erro
         })
         .await?;
 
-    let expected = HashSet::from_iter(["Cat".to_string(), "Catwoman".to_string()]);
+    let expected = HashSet::from_iter([
+        "Cat".to_string(),
+        "Catwoman".to_string(),
+        "Batman".to_string(),
+    ]);
     assert!(response.get_ref().prefix.is_some());
     let prefix_response = response.get_ref().prefix.as_ref().unwrap();
     let results = prefix_response
