@@ -32,7 +32,6 @@ use tantivy::{DocId, InvertedIndexReader, Term};
 use crate::fuzzy_query::FuzzyTermQuery;
 use crate::schema::{self, ParagraphSchema};
 use crate::stop_words::is_stop_word;
-
 type QueryP = (Occur, Box<dyn Query>);
 
 // Used to identify the terms matched by tantivy
@@ -351,7 +350,7 @@ pub fn suggest_query(
     request
         .filter
         .iter()
-        .flat_map(|f| f.tags.iter())
+        .flat_map(|f| f.field_labels.iter())
         .flat_map(|facet_key| Facet::from_text(facet_key).ok().into_iter())
         .for_each(|facet| {
             let facet_term = Term::from_facet(schema.facets, &facet);
@@ -444,25 +443,62 @@ pub fn search_query(
         fuzzies.push((Occur::Must, field_filter.clone()));
         originals.push((Occur::Must, field_filter));
     }
-    // Add filter
+    // Label filters
+    let mut label_filters: Vec<Box<dyn Query>> = vec![];
     search
         .filter
         .iter()
-        .flat_map(|f| f.tags.iter())
+        .flat_map(|f| f.field_labels.iter())
         .flat_map(|facet_key| Facet::from_text(facet_key).ok().into_iter())
         .for_each(|facet| {
             let facet_term = Term::from_facet(schema.facets, &facet);
             let facet_term_query = TermQuery::new(facet_term, IndexRecordOption::Basic);
-            fuzzies.push((Occur::Must, Box::new(facet_term_query.clone())));
-            originals.push((Occur::Must, Box::new(facet_term_query)));
+            label_filters.push(Box::new(facet_term_query));
         });
-    // Keys
-    search.key_filters.iter().for_each(|uuid| {
+    search
+        .filter
+        .iter()
+        .flat_map(|f| f.paragraph_labels.iter())
+        .flat_map(|facet_key| Facet::from_text(facet_key).ok().into_iter())
+        .for_each(|facet| {
+            let facet_term = Term::from_facet(schema.facets, &facet);
+            let facet_term_query = TermQuery::new(facet_term, IndexRecordOption::Basic);
+            label_filters.push(Box::new(facet_term_query));
+        });
+    if !label_filters.is_empty() {
+        let label_filters_query = Box::new(BooleanQuery::intersection(label_filters));
+        fuzzies.push((Occur::Must, label_filters_query.clone()));
+        originals.push((Occur::Must, label_filters_query));
+    }
+
+    // Keys filter
+    let mut key_filters: Vec<Box<dyn Query>> = vec![];
+    search.key_filters.iter().for_each(|key| {
+        let mut key_filter: Vec<Box<dyn Query>> = vec![];
+
+        let parts: Vec<String> = key.split('/').map(str::to_string).collect();
+        let uuid = &parts[0];
         let term = Term::from_field_text(schema.uuid, uuid);
         let term_query = TermQuery::new(term, IndexRecordOption::Basic);
-        fuzzies.push((Occur::Must, Box::new(term_query.clone())));
-        originals.push((Occur::Must, Box::new(term_query)));
+        key_filter.push(Box::new(term_query));
+
+        if parts.len() >= 3 {
+            let mut field_key: String = "/".to_owned();
+            field_key.push_str(&parts[1..3].join("/"));
+            let facet = Facet::from_text(&field_key).unwrap();
+            let facet_term = Term::from_facet(schema.field, &facet);
+            let facet_term_query = TermQuery::new(facet_term, IndexRecordOption::Basic);
+            key_filter.push(Box::new(facet_term_query));
+        }
+
+        let key_filter_query = Box::new(BooleanQuery::intersection(key_filter));
+        key_filters.push(key_filter_query);
     });
+    if !key_filters.is_empty() {
+        let key_filters_query = Box::new(BooleanQuery::union(key_filters));
+        fuzzies.push((Occur::Must, key_filters_query.clone()));
+        originals.push((Occur::Must, key_filters_query));
+    }
 
     if originals.len() == 1 && originals[0].1.is::<AllQuery>() {
         let original = originals.pop().unwrap().1;
@@ -484,7 +520,7 @@ pub fn streaming_query(schema: &ParagraphSchema, request: &StreamRequest) -> Box
     request
         .filter
         .iter()
-        .flat_map(|f| f.tags.iter())
+        .flat_map(|f| f.labels.iter())
         .flat_map(|facet_key| Facet::from_text(facet_key).ok().into_iter())
         .for_each(|facet| {
             let facet_term = Term::from_facet(schema.facets, &facet);
