@@ -44,6 +44,22 @@ pub struct IndexMessage {
     pub storage_key: ::prost::alloc::string::String,
     #[prost(string, tag="9")]
     pub kbid: ::prost::alloc::string::String,
+    #[prost(enumeration="IndexMessageSource", tag="10")]
+    pub source: i32,
+}
+#[derive(Clone, PartialEq, ::prost::Message)]
+pub struct GarbageCollectorResponse {
+    #[prost(enumeration="garbage_collector_response::Status", tag="1")]
+    pub status: i32,
+}
+/// Nested message and enum types in `GarbageCollectorResponse`.
+pub mod garbage_collector_response {
+    #[derive(Clone, Copy, Debug, PartialEq, Eq, Hash, PartialOrd, Ord, ::prost::Enumeration)]
+    #[repr(i32)]
+    pub enum Status {
+        Ok = 0,
+        TryLater = 1,
+    }
 }
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct NewShardRequest {
@@ -69,6 +85,12 @@ pub enum TypeMessage {
     Creation = 0,
     Deletion = 1,
 }
+#[derive(Clone, Copy, Debug, PartialEq, Eq, Hash, PartialOrd, Ord, ::prost::Enumeration)]
+#[repr(i32)]
+pub enum IndexMessageSource {
+    Processor = 0,
+    Writer = 1,
+}
 /// Generated client implementations.
 pub mod node_writer_client {
     #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
@@ -224,10 +246,7 @@ pub mod node_writer_client {
         pub async fn gc(
             &mut self,
             request: impl tonic::IntoRequest<super::super::noderesources::ShardId>,
-        ) -> Result<
-            tonic::Response<super::super::noderesources::EmptyResponse>,
-            tonic::Status,
-        > {
+        ) -> Result<tonic::Response<super::GarbageCollectorResponse>, tonic::Status> {
             self.inner
                 .ready()
                 .await
@@ -401,10 +420,7 @@ pub mod node_writer_server {
         async fn gc(
             &self,
             request: tonic::Request<super::super::noderesources::ShardId>,
-        ) -> Result<
-            tonic::Response<super::super::noderesources::EmptyResponse>,
-            tonic::Status,
-        >;
+        ) -> Result<tonic::Response<super::GarbageCollectorResponse>, tonic::Status>;
         async fn set_resource(
             &self,
             request: tonic::Request<super::super::noderesources::Resource>,
@@ -649,7 +665,7 @@ pub mod node_writer_server {
                         T: NodeWriter,
                     > tonic::server::UnaryService<super::super::noderesources::ShardId>
                     for GCSvc<T> {
-                        type Response = super::super::noderesources::EmptyResponse;
+                        type Response = super::GarbageCollectorResponse;
                         type Future = BoxFuture<
                             tonic::Response<Self::Response>,
                             tonic::Status,
